@@ -2,15 +2,16 @@
 compile_scss <- function(data, id = NULL) {
 
   # Obtain the SCSS options table from `data`
+  gt_options_tbl <- dt_options_get(data = data)
+
+  gt_options_tbl <- gt_options_tbl[gt_options_tbl$scss & !is.na(gt_options_tbl$value), ]
+
+  color_rows <- grepl("_color", gt_options_tbl$parameter)
+
   gt_options_tbl <-
-    dt_options_get(data = data) %>%
-    dplyr::filter(scss) %>%
-    dplyr::filter(!is.na(value)) %>%
-    dplyr::mutate(
-      value = {
-        color_rows <- grepl("_color", .data$parameter)
-        value[color_rows] <- lapply(value[color_rows], html_color)
-        value
+    within(
+      gt_options_tbl,{
+        value[color_rows] = value[color_rows] <- lapply(value[color_rows], html_color)
       }
     )
 
@@ -28,7 +29,7 @@ compile_scss <- function(data, id = NULL) {
 
   # Combine any additional CSS statements and separate with `\n`
   if (has_additional_css) {
-    table_additional_css <- paste(additional_css, collapse = "\n") %>% paste_right("\n")
+    table_additional_css <- paste0(paste(additional_css, collapse = "\n"),  "\n")
   }
 
   sass::sass(
