@@ -12,15 +12,11 @@ dt_formats_init <- function(data) {
   dt_formats_set(data = data, formats = list())
 }
 
-dt_formats_add <- function(data, formats, prepend) {
+dt_formats_add <- function(data, formats) {
 
   formats_list <- dt_formats_get(data = data)
 
-  if (prepend) {
-    formats <- prepend_vec(list(formats), values = formats_list)
-  } else {
-    formats <- append(list(formats), values = formats_list)
-  }
+  formats <- append(formats_list, values = list(formats))
 
   dt_formats_set(data = data, formats = formats)
 }
