@@ -1,7 +1,3 @@
-######
-# General String Formatters
-######
-
 #' Flexibly split a string into two pieces
 #'
 #' @param x The string to split into a character vector of length 2.
@@ -98,7 +94,7 @@ split_string_2 <- function(
 
     # Define the start and stop positions as
     # the single `input` value
-    split_start <- split_stop <- input %>% as.numeric()
+    split_start <- split_stop <- as.numeric(input)
   }
 
   # Perform the split either before the matched characters
@@ -252,8 +248,8 @@ swap_adjacent_text_groups <- function(
       }
 
       # Get the start and stop positions for the text groups
-      group_1 <- x %>% get_start_stop_positions(pattern = pattern_1)
-      group_2 <- x %>% get_start_stop_positions(pattern = pattern_2)
+      group_1 <- get_start_stop_positions(x, pattern = pattern_1)
+      group_2 <- get_start_stop_positions(x, pattern = pattern_2)
 
       # Return `x` as is if the patterns don't encompass text ranges
       # that aren't adjacent
@@ -304,7 +300,7 @@ get_start_stop_positions <- function(x, pattern) {
   regexpr_out <- regexpr(pattern, x)
 
   # Define the start position for the matched characters
-  start_pos <- regexpr_out %>% as.numeric()
+  start_pos <- as.numeric(regexpr_out)
 
   # Define the stop position for the matched characters
   stop_pos <- attr(regexpr_out, "match.length", exact = TRUE) + start_pos - 1
@@ -345,8 +341,8 @@ str_catalog <- function(
 
   item_count <- length(item_vector)
 
-  surround_str_1 <- rev(surround) %>% paste(collapse = "")
-  surround_str_2 <- surround %>% paste(collapse = "")
+  surround_str_1 <- paste(rev(surround), collapse = "")
+  surround_str_2 <- paste(surround, collapse = "")
 
   cat_str <- paste0(surround_str_1, item_vector, surround_str_2)
 
@@ -367,9 +363,7 @@ str_catalog <- function(
     }
 
     separators[length(separators)] <-
-      separators[length(separators)] %>%
-      paste_right(conj) %>%
-      paste_right(" ")
+      paste_right(paste_right(separators[length(separators)], conj), " ")
 
     separators[length(separators) + 1] <- ""
 
@@ -379,6 +373,150 @@ str_catalog <- function(
   }
 }
 
+str_substitute <- function(string, start = 1L, end = -1L) {
+
+  if (is.matrix(start)) {
+    end <- start[, 2]
+    start <- start[, 1]
+  }
+
+  start <- recycler(start, string)
+  end <- recycler(end, string)
+
+  n <- nchar(string)
+  start <- ifelse(start < 0, start + n + 1, start)
+  end <- ifelse(end < 0, end + n + 1, end)
+
+  substr(string, start, end)
+}
+
+recycler <- function(x, to, arg = deparse(substitute(x))) {
+
+  if (length(x) == length(to)) {
+    return(x)
+  }
+
+  if (length(x) != 1) {
+    stop("Can't recycle `", arg, "` to length ", length(to), call. = FALSE)
+  }
+
+  rep(x, length(to))
+}
+
+str_complete_locate <- function(string, pattern) {
+  out <- gregexpr(pattern, string, perl = TRUE)
+  lapply(out, location, all = TRUE)
+}
+
+str_single_locate <- function(string, pattern) {
+  out <- regexpr(pattern, string, perl = TRUE)
+  location(out)
+}
+
+str_complete_replace <- function(string, pattern, replacement) {
+  gsub(pattern, replacement, string, perl = TRUE)
+}
+
+str_single_replace <- function(string, pattern, replacement) {
+  sub(pattern, replacement, string, perl = TRUE)
+}
+
+location <- function(x, all = FALSE) {
+
+  start <- as.vector(x)
+  if (all && identical(start, -1L)) {
+    return(cbind(start = integer(), end = integer()))
+  }
+  end <- as.vector(x) + attr(x, "match.length") - 1
+
+  no_match <- start == -1L
+  start[no_match] <- NA
+  end[no_match] <- NA
+
+  cbind(start = start, end = end)
+}
+
+str_complete_extract <- function(string, pattern) {
+
+  loc <- str_complete_locate(string, pattern)
+  lapply(seq_along(string), function(i) {
+    loc <- loc[[i]]
+    str_substitute(rep(string[[i]], nrow(loc)), loc)
+  })
+}
+
+str_single_extract <- function(string, pattern) {
+  str_substitute(string, str_single_locate(string, pattern))
+}
+
+str_get_match <- function(string, pattern) {
+
+  loc <- regexec(pattern, string, perl = TRUE)
+  loc <- lapply(loc, location)
+
+  out <- lapply(seq_along(string), function(i) {
+    loc <- loc[[i]]
+    str_substitute(rep(string[[i]], nrow(loc)), loc)
+  })
+  do.call("rbind", out)
+}
+
+str_has_match <- function(string, pattern, negate = FALSE) {
+
+  out <- grepl(pattern, string, perl = TRUE)
+  out[is.na(string)] <- NA
+
+  if (negate) {
+    !out
+  } else {
+    out
+  }
+}
+
+str_trim_sides <- function(string) {
+  sub("\\s+$", "", sub("^\\s+", "", string))
+}
+
+alnum_id <- function(x, exclude = '[^[:alnum:]]+') {
+  tolower(gsub('^-+|-+$', '', gsub(exclude, '-', x, perl = TRUE)))
+}
+
+create_unique_id_vals <- function(
+    x,
+    simplify = TRUE,
+    exclude = "[^[:alnum:]]+",
+    na_is_index = TRUE,
+    sep = "__"
+) {
+
+  if (simplify) {
+    x <- tolower(gsub("^-+|-+$", "", gsub(exclude, "-", x, perl = TRUE)))
+  }
+
+  id_vals <- rep(NA_character_, length(x))
+
+  for (i in seq_along(x)) {
+
+    if (is.na(x[i])) {
+      if (na_is_index) {
+        id_vals[i] <- as.character(i)
+      } else {
+        id_vals[i] <- random_id()
+      }
+    }
+
+    if (!is.na(x[i])) {
+      id_vals[i] <- x[i]
+    }
+
+    if (i > 1 && id_vals[i] %in% id_vals[1:(i - 1)]) {
+      id_vals[i] <- paste0(id_vals[i], sep, formatC(i, width = 3, flag = "0"))
+    }
+  }
+
+  id_vals
+}
+
 glue_gt <- function(.x, ...) {
   glue::glue_data(.x, ..., .transformer = get, .envir = emptyenv())
 }
