@@ -31,6 +31,7 @@ utils::globalVariables(
     "b",
     "blue",
     "built",
+    "built_group_label",
     "boxhead",
     "category",
     "colname",
@@ -49,9 +50,11 @@ utils::globalVariables(
     "date_added",
     "designer",
     "display_name",
+    "flexible",
     "footnotes",
     "footnotes_to_list",
     "formatted",
+    "format_code",
     "fs_id",
     "fs_id_coalesced",
     "get_groups_rows",
@@ -62,6 +65,8 @@ utils::globalVariables(
     "groups",
     "grpname",
     "grprow",
+    "i",
+    "id",
     "integrate_summary_lines",
     "label",
     "locname",
@@ -75,17 +80,20 @@ utils::globalVariables(
     "package",
     "palette",
     "red",
+    "row_id",
     "row_end",
     "row_start",
     "rownum",
     "rownum_i",
     "spanner_id",
+    "spanner_label",
     "spanner_level",
     "styles",
     "styles_appended",
     "symbol",
     "text",
     "time_part",
+    "time_type",
     "Var1",
     "base_locale_id",
     "dec_sep",
