@@ -1,5 +1,3 @@
-context("Ensuring that the `cols_width()` function works as expected")
-
 # Create a table with four columns of values
 tbl <-
   dplyr::tribble(
@@ -41,20 +39,13 @@ check_suggests <- function() {
 
 # Gets the HTML attr value from a single key
 selection_value <- function(html, key) {
-
   selection <- paste0("[", key, "]")
-
-  html %>%
-    rvest::html_nodes(selection) %>%
-    rvest::html_attr(key)
+  rvest::html_attr(rvest::html_nodes(html, selection), key)
 }
 
 # Gets the inner HTML text from a single value
 selection_text <- function(html, selection) {
-
-  html %>%
-    rvest::html_nodes(selection) %>%
-    rvest::html_text()
+  rvest::html_text(rvest::html_nodes(html, selection))
 }
 
 # Helper function to compare a contiguous set of HTML fragments with raw html
