@@ -1,3 +1,5 @@
+skip_on_os("linux")
+
 library(lubridate)
 
 test_that("the `fmt_date()` function works correctly", {
@@ -70,60 +72,74 @@ test_that("the `fmt_date()` function works correctly", {
       (tab %>%
          fmt_date(columns = "date", date_style = 2) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("Sunday, October 15, 2017", "Friday, February 22, 2013",
+      c(
+        "Sunday, October 15, 2017", "Friday, February 22, 2013",
         "Monday, September 22, 2014", "Wednesday, January 10, 2018",
-        "Saturday, January 1, 2000")
+        "Saturday, January 1, 2000"
+      )
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 3) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("Sun, Oct 15, 2017", "Fri, Feb 22, 2013",
+      c(
+        "Sun, Oct 15, 2017", "Fri, Feb 22, 2013",
         "Mon, Sep 22, 2014", "Wed, Jan 10, 2018",
-        "Sat, Jan 1, 2000")
+        "Sat, Jan 1, 2000"
+      )
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 4) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("Sunday 15 October 2017", "Friday 22 February 2013",
+      c(
+        "Sunday 15 October 2017", "Friday 22 February 2013",
         "Monday 22 September 2014", "Wednesday 10 January 2018",
-        "Saturday 1 January 2000")
+        "Saturday 1 January 2000"
+      )
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 5) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("October 15, 2017", "February 22, 2013",
+      c(
+        "October 15, 2017", "February 22, 2013",
         "September 22, 2014", "January 10, 2018",
-        "January 1, 2000")
+        "January 1, 2000"
+      )
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 6) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("Oct 15, 2017", "Feb 22, 2013", "Sep 22, 2014",
-        "Jan 10, 2018", "Jan 1, 2000")
+      c(
+        "Oct 15, 2017", "Feb 22, 2013", "Sep 22, 2014",
+        "Jan 10, 2018", "Jan 1, 2000"
+      )
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 7) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("15 Oct 2017", "22 Feb 2013", "22 Sep 2014",
-        "10 Jan 2018", "1 Jan 2000")
+      c(
+        "15 Oct 2017", "22 Feb 2013", "22 Sep 2014",
+        "10 Jan 2018", "1 Jan 2000"
+      )
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 8) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("15 October 2017", "22 February 2013", "22 September 2014",
-        "10 January 2018", "1 January 2000")
+      c(
+        "15 October 2017", "22 February 2013", "22 September 2014",
+        "10 January 2018", "1 January 2000"
+      )
     )
 
     expect_equal(
@@ -137,34 +153,41 @@ test_that("the `fmt_date()` function works correctly", {
       (tab %>%
          fmt_date(columns = "date", date_style = 10) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("2017", "2013", "2014", "2018", "2000")
+      c("15 Oct", "22 Feb", "22 Sep", "10 Jan", "1 Jan")
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 11) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("October", "February", "September", "January", "January")
+      c("2017", "2013", "2014", "2018", "2000")
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 12) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("15", "22", "22", "10", "01")
+      c("October", "February", "September", "January", "January")
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 13) %>%
          render_formats_test(context = "html"))[["date"]],
-      c("2017/10/15", "2013/02/22", "2014/09/22", "2018/01/10", "2000/01/01")
+      c("15", "22", "22", "10", "01")
     )
 
     expect_equal(
       (tab %>%
          fmt_date(columns = "date", date_style = 14) %>%
          render_formats_test(context = "html"))[["date"]],
+      c("2017/10/15", "2013/02/22", "2014/09/22", "2018/01/10", "2000/01/01")
+    )
+
+    expect_equal(
+      (tab %>%
+         fmt_date(columns = "date", date_style = 15) %>%
+         render_formats_test(context = "html"))[["date"]],
       c("17/10/15", "13/02/22", "14/09/22", "18/01/10", "00/01/01")
     )
   }
@@ -398,14 +421,14 @@ test_that("the `fmt_time()` function works correctly", {
       gt() %>%
       fmt_time(columns = "date") %>%
       render_formats_test(context = "default"))[["date"]],
-    rep("00:00", 2)
+    rep("00:00:00", 2)
   )
   expect_equal(
     (dplyr::tibble(date = c("2013-12-30", "2017-03-15 12:30")) %>%
        gt() %>%
        fmt_time(columns = "date") %>%
        render_formats_test(context = "default"))[["date"]],
-    rep("00:00", 2)
+    rep("00:00:00", 2)
   )
 
   # Don't expect an error if any string-based date-times have invalid
@@ -548,7 +571,9 @@ test_that("the `fmt_datetime()` function works correctly", {
     expect_equal(
       (tab %>%
          fmt_datetime(
-           columns = "datetime", format = "%F", tz = NULL
+           columns = "datetime",
+           format = "%F",
+           tz = NULL
          ) %>%
          render_formats_test(context = "default"))[["datetime"]],
       c("2017-06-10", "2017-07-12", "2017-08-05", "2017-10-23", "2000-01-01")
@@ -557,21 +582,9 @@ test_that("the `fmt_datetime()` function works correctly", {
     expect_equal(
       (tab %>%
          fmt_datetime(
-           columns = "datetime", format = "%B %d, %Y %H:%M:%S", tz = NULL
-         ) %>%
-         render_formats_test(context = "default"))[["datetime"]],
-      c(
-        "June 10, 2017 12:35:23", "July 12, 2017 15:01:34",
-        "August 05, 2017 09:45:23", "October 23, 2017 01:32:00",
-        "January 01, 2000 00:00:00"
-      )
-    )
-
-    expect_equal(
-      (tab %>%
-         fmt_datetime(
-           columns = "datetime", date_style = 2, time_style = 2,
-           format = "%B %d, %Y %H:%M:%S", tz = NULL
+           columns = "datetime",
+           format = "%B %d, %Y %H:%M:%S",
+           tz = NULL
          ) %>%
          render_formats_test(context = "default"))[["datetime"]],
       c(
@@ -585,7 +598,25 @@ test_that("the `fmt_datetime()` function works correctly", {
       (tab %>%
          fmt_datetime(
            columns = "datetime",
-           format = "%B %d, %Y %H:%M:%S (%z)", tz = NULL
+           date_style = 1,
+           time_style = 1,
+           format = "%B %d, %Y %H:%M:%S",
+           tz = NULL
+         ) %>%
+         render_formats_test(context = "default"))[["datetime"]],
+      c(
+        "June 10, 2017 12:35:23", "July 12, 2017 15:01:34",
+        "August 05, 2017 09:45:23", "October 23, 2017 01:32:00",
+        "January 01, 2000 00:00:00"
+      )
+    )
+
+    expect_equal(
+      (tab %>%
+         fmt_datetime(
+           columns = "datetime",
+           format = "%B %d, %Y %H:%M:%S (%z)",
+           tz = NULL
          ) %>%
          render_formats_test(context = "default"))[["datetime"]],
       c(
@@ -597,18 +628,97 @@ test_that("the `fmt_datetime()` function works correctly", {
   }
 
   # Using a string to represent a date or date-time doesn't allow the
-  # output time to be altered by `tz`
+  # output time to be altered by `tz` but it should change the tz
+  # that is displayed
   expect_equal(
-    gt_tables[[1]] %>% # table where `datetime` column was `character`
-      fmt_datetime(
-        columns = "datetime",
-        format = "%B %d, %Y %H:%M:%S (%z)", tz = "GMT"
-      ) %>% render_formats_test(context = "default"),
-    gt_tables[[1]] %>%
-      fmt_datetime(
-        columns = "datetime",
-        format = "%B %d, %Y %H:%M:%S (%z)", tz = "America/Toronto"
-      ) %>% render_formats_test(context = "default")
+    (gt_tables[[1]] %>% # table where `datetime` column was `character`
+       fmt_datetime(
+         columns = "datetime",
+         format = "%B %d, %Y %H:%M:%S (%z)",
+         tz = "GMT"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "June 10, 2017 12:35:23 (+0000)", "July 12, 2017 15:01:34 (+0000)",
+      "August 05, 2017 09:45:23 (+0000)", "October 23, 2017 01:32:00 (+0000)",
+      "January 01, 2000 00:00:00 (+0000)"
+    )
+  )
+
+  expect_equal(
+    (gt_tables[[1]] %>% # table where `datetime` column was `character`
+       fmt_datetime(
+         columns = "datetime",
+         format = "%B %d, %Y %H:%M:%S (%z)",
+         tz = "America/Toronto"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "June 10, 2017 12:35:23 (-0400)", "July 12, 2017 15:01:34 (-0400)",
+      "August 05, 2017 09:45:23 (-0400)", "October 23, 2017 01:32:00 (-0400)",
+      "January 01, 2000 00:00:00 (-0500)"
+    )
+  )
+
+  expect_equal(
+    (gt_tables[[1]] %>% # table where `datetime` column was `character`
+       fmt_datetime(
+         columns = "datetime",
+         format = "%B %d, %Y %H:%M:%S (%z)",
+         tz = "America/Vancouver"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "June 10, 2017 12:35:23 (-0700)", "July 12, 2017 15:01:34 (-0700)",
+      "August 05, 2017 09:45:23 (-0700)", "October 23, 2017 01:32:00 (-0700)",
+      "January 01, 2000 00:00:00 (-0800)"
+    )
+  )
+
+
+  expect_equal(
+    (gt_tables[[1]] %>% # table where `datetime` column was `character`
+       fmt_datetime(
+         columns = "datetime",
+         format = "MMMM d, y HH:mm:ss (Z)",
+         tz = "GMT"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "June 10, 2017 12:35:23 (+0000)", "July 12, 2017 15:01:34 (+0000)",
+      "August 5, 2017 09:45:23 (+0000)", "October 23, 2017 01:32:00 (+0000)",
+      "January 1, 2000 00:00:00 (+0000)"
+    )
+  )
+
+  expect_equal(
+    (gt_tables[[1]] %>% # table where `datetime` column was `character`
+       fmt_datetime(
+         columns = "datetime",
+         format = "MMMM d, y HH:mm:ss (Z)",
+         tz = "America/Toronto"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "June 10, 2017 12:35:23 (-0400)", "July 12, 2017 15:01:34 (-0400)",
+      "August 5, 2017 09:45:23 (-0400)", "October 23, 2017 01:32:00 (-0400)",
+      "January 1, 2000 00:00:00 (-0500)"
+    )
+  )
+
+  expect_equal(
+    (gt_tables[[1]] %>% # table where `datetime` column was `character`
+       fmt_datetime(
+         columns = "datetime",
+         format = "MMMM d, y HH:mm:ss (Z)",
+         tz = "America/Vancouver"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "June 10, 2017 12:35:23 (-0700)", "July 12, 2017 15:01:34 (-0700)",
+      "August 5, 2017 09:45:23 (-0700)", "October 23, 2017 01:32:00 (-0700)",
+      "January 1, 2000 00:00:00 (-0800)"
+    )
   )
 
   # Using a POSIXct-formatted date-time *does* allow
@@ -617,7 +727,8 @@ test_that("the `fmt_datetime()` function works correctly", {
     (gt_tables[[2]] %>%
        fmt_datetime(
          columns = "datetime",
-         format = "%B %d, %Y %H:%M:%S (%z)", tz = "America/Toronto"
+         format = "%B %d, %Y %H:%M:%S (%z)",
+         tz = "America/Toronto"
        ) %>%
        render_formats_test(context = "default"))[["datetime"]],
     c(
@@ -626,11 +737,28 @@ test_that("the `fmt_datetime()` function works correctly", {
       "December 31, 1999 19:00:00 (-0500)"
     )
   )
+
   expect_equal(
     (gt_tables[[2]] %>%
        fmt_datetime(
          columns = "datetime",
-         format = "%B %d, %Y %H:%M:%S (%z)", tz = "Asia/Tokyo"
+         format = "MMMM d, y HH:mm:ss (Z)",
+         tz = "America/Toronto"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "June 10, 2017 08:35:23 (-0400)", "July 12, 2017 11:01:34 (-0400)",
+      "August 5, 2017 05:45:23 (-0400)", "October 22, 2017 21:32:00 (-0400)",
+      "December 31, 1999 19:00:00 (-0500)"
+    )
+  )
+
+  expect_equal(
+    (gt_tables[[2]] %>%
+       fmt_datetime(
+         columns = "datetime",
+         format = "%B %d, %Y %H:%M:%S (%z)",
+         tz = "Asia/Tokyo"
        ) %>%
        render_formats_test(context = "default"))[["datetime"]],
     c(
@@ -640,6 +768,21 @@ test_that("the `fmt_datetime()` function works correctly", {
     )
   )
 
+  expect_equal(
+    (gt_tables[[2]] %>%
+       fmt_datetime(
+         columns = "datetime",
+         format = "MMMM d, y HH:mm:ss (Z)",
+         tz = "Asia/Tokyo"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "June 10, 2017 21:35:23 (+0900)", "July 13, 2017 00:01:34 (+0900)",
+      "August 5, 2017 18:45:23 (+0900)", "October 23, 2017 10:32:00 (+0900)",
+      "January 1, 2000 09:00:00 (+0900)"
+    )
+  )
+
   # Create a table with datetime values set in JST
   datetime_jst_tbl <-
     dplyr::tibble(datetime = c(
@@ -667,7 +810,22 @@ test_that("the `fmt_datetime()` function works correctly", {
        gt() %>%
        fmt_datetime(
          columns = "datetime",
-         format = "%B %d, %Y %H:%M:%S (%z)", tz = "Asia/Tokyo"
+         format = "%B %d, %Y %H:%M:%S (%z)", # strftime pattern
+         tz = "Asia/Tokyo"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "October 15, 2017 12:35:23 (+0900)", "February 22, 2013 15:01:34 (+0900)",
+      "September 22, 2014 09:45:23 (+0900)", "January 10, 2018 01:32:00 (+0900)"
+    )
+  )
+  expect_equal(
+    (datetime_jst_tbl %>%
+       gt() %>%
+       fmt_datetime(
+         columns = "datetime",
+         format = "MMMM d, y HH:mm:ss (Z)", # fdt pattern
+         tz = "Asia/Tokyo"
        ) %>%
        render_formats_test(context = "default"))[["datetime"]],
     c(
@@ -683,7 +841,8 @@ test_that("the `fmt_datetime()` function works correctly", {
        gt() %>%
        fmt_datetime(
          columns = "datetime",
-         format = "%B %d, %Y %H:%M:%S (%z)", tz = "America/Toronto"
+         format = "%B %d, %Y %H:%M:%S (%z)",
+         tz = "America/Toronto"
        ) %>%
        render_formats_test(context = "default"))[["datetime"]],
     c(
@@ -691,6 +850,20 @@ test_that("the `fmt_datetime()` function works correctly", {
       "September 21, 2014 20:45:23 (-0400)", "January 09, 2018 11:32:00 (-0500)"
     )
   )
+  expect_equal(
+    (datetime_jst_tbl %>%
+       gt() %>%
+       fmt_datetime(
+         columns = "datetime",
+         format = "MMMM d, y HH:mm:ss (Z)",
+         tz = "America/Toronto"
+       ) %>%
+       render_formats_test(context = "default"))[["datetime"]],
+    c(
+      "October 14, 2017 23:35:23 (-0400)", "February 22, 2013 01:01:34 (-0500)",
+      "September 21, 2014 20:45:23 (-0400)", "January 9, 2018 11:32:00 (-0500)"
+    )
+  )
 
   # Create a gt table with a `time` column containing valid time strings
   tab_3 <-
@@ -705,8 +878,43 @@ test_that("the `fmt_datetime()` function works correctly", {
 
   expect_equal(
     (tab_3 %>%
-       fmt_datetime(columns = "time", format = "%I:%M:%S %P") %>%
+       fmt_datetime(
+         columns = "time",
+         format = "%I:%M:%S %P"
+       ) %>%
        render_formats_test(context = "default"))[["time"]],
     c("12:35:23 pm", "03:01:34 pm", "09:45:23 am", "01:32:00 am", "12:00:00 am")
   )
+
+  expect_equal(
+    (tab_3 %>%
+       fmt_datetime(
+         columns = "time",
+         format = "%I:%M:%S %P",
+         tz = "America/Vancouver"
+       ) %>%
+       render_formats_test(context = "default"))[["time"]],
+    c("12:35:23 pm", "03:01:34 pm", "09:45:23 am", "01:32:00 am", "12:00:00 am")
+  )
+
+  expect_equal(
+    (tab_3 %>%
+       fmt_datetime(
+         columns = "time",
+         format = "h:mm:ss a"
+       ) %>%
+       render_formats_test(context = "default"))[["time"]],
+    c("12:35:23 PM", "3:01:34 PM", "9:45:23 AM", "1:32:00 AM", "12:00:00 AM")
+  )
+
+  expect_equal(
+    (tab_3 %>%
+       fmt_datetime(
+         columns = "time",
+         format = "h:mm:ss a",
+         tz = "America/Vancouver"
+       ) %>%
+       render_formats_test(context = "default"))[["time"]],
+    c("12:35:23 PM", "3:01:34 PM", "9:45:23 AM", "1:32:00 AM", "12:00:00 AM")
+  )
 })
