@@ -67,24 +67,61 @@ test_that("certain `fmt_*()` functions stop if given incompatible column data",
   expect_error(gt_tbl %>% fmt_number(columns = c(num, fctr)))
   expect_error(gt_tbl %>% fmt_number(columns = char))
 
+  # Tests with `fmt_integer()`
+  gt_tbl %>% fmt_integer(columns = num) %>% expect_s3_class("gt_tbl")
+  gt_tbl %>% fmt_integer(columns = c()) %>% expect_s3_class("gt_tbl")
+  gt_tbl %>% fmt_integer(columns = currency) %>% expect_s3_class("gt_tbl")
+  expect_error(gt_tbl %>% fmt_integer(columns = c(num, fctr)))
+  expect_error(gt_tbl %>% fmt_integer(columns = char))
+
   # Tests with `fmt_scientific()`
   gt_tbl %>% fmt_scientific(columns = num) %>% expect_s3_class("gt_tbl")
   gt_tbl %>% fmt_scientific(columns = c()) %>% expect_s3_class("gt_tbl")
   expect_error(gt_tbl %>% fmt_scientific(columns = c(num, fctr)))
   expect_error(gt_tbl %>% fmt_scientific(columns = char))
 
+  # Tests with `fmt_engineering()`
+  gt_tbl %>% fmt_engineering(columns = num) %>% expect_s3_class("gt_tbl")
+  gt_tbl %>% fmt_engineering(columns = c()) %>% expect_s3_class("gt_tbl")
+  expect_error(gt_tbl %>% fmt_engineering(columns = c(num, fctr)))
+  expect_error(gt_tbl %>% fmt_engineering(columns = char))
+
   # Tests with `fmt_percent()`
   gt_tbl %>% fmt_percent(columns = num) %>% expect_s3_class("gt_tbl")
   gt_tbl %>% fmt_percent(columns = c()) %>% expect_s3_class("gt_tbl")
   expect_error(gt_tbl %>% fmt_percent(columns = c(num, fctr)))
   expect_error(gt_tbl %>% fmt_percent(columns = char))
 
+  # Tests with `fmt_partsper()`
+  gt_tbl %>% fmt_partsper(columns = num) %>% expect_s3_class("gt_tbl")
+  gt_tbl %>% fmt_partsper(columns = c()) %>% expect_s3_class("gt_tbl")
+  expect_error(gt_tbl %>% fmt_partsper(columns = c(num, fctr)))
+  expect_error(gt_tbl %>% fmt_partsper(columns = char))
+
+  # Tests with `fmt_fraction()`
+  gt_tbl %>% fmt_fraction(columns = num) %>% expect_s3_class("gt_tbl")
+  gt_tbl %>% fmt_fraction(columns = c()) %>% expect_s3_class("gt_tbl")
+  expect_error(gt_tbl %>% fmt_fraction(columns = c(num, fctr)))
+  expect_error(gt_tbl %>% fmt_fraction(columns = char))
+
   # Tests with `fmt_currency()`
   gt_tbl %>% fmt_currency(columns = num) %>% expect_s3_class("gt_tbl")
   gt_tbl %>% fmt_currency(columns = c()) %>% expect_s3_class("gt_tbl")
   expect_error(gt_tbl %>% fmt_currency(columns = c(num, fctr)))
   expect_error(gt_tbl %>% fmt_currency(columns = char))
 
+  # Tests with `fmt_roman()`
+  gt_tbl %>% fmt_roman(columns = num) %>% expect_s3_class("gt_tbl")
+  gt_tbl %>% fmt_roman(columns = c()) %>% expect_s3_class("gt_tbl")
+  expect_error(gt_tbl %>% fmt_roman(columns = c(num, fctr)))
+  expect_error(gt_tbl %>% fmt_roman(columns = char))
+
+  # Tests with `fmt_bytes()`
+  gt_tbl %>% fmt_bytes(columns = num) %>% expect_s3_class("gt_tbl")
+  gt_tbl %>% fmt_bytes(columns = c()) %>% expect_s3_class("gt_tbl")
+  expect_error(gt_tbl %>% fmt_bytes(columns = c(num, fctr)))
+  expect_error(gt_tbl %>% fmt_bytes(columns = char))
+
   # Tests with `fmt_date()`
   gt_tbl %>% fmt_date(columns = date) %>% expect_s3_class("gt_tbl")
   gt_tbl %>% fmt_date(columns = c()) %>% expect_s3_class("gt_tbl")
